Blob Blame History Raw
diff -up ./tests/common/init.sh.sql-default-tests ./tests/common/init.sh
--- ./tests/common/init.sh.sql-default-tests	2021-05-28 02:50:43.000000000 -0700
+++ ./tests/common/init.sh	2021-06-03 15:44:45.771708842 -0700
@@ -651,9 +651,9 @@ if [ -z "${INIT_SOURCED}" -o "${INIT_SOU
 
     RELOAD_CRL=1
 
-    # if test mode isn't set, test scripts default to expecting sql
+    # if test mode isn't set, test scripts default to expecting dbm
     if [ "${TEST_MODE}" = "" ]; then
-        NSS_DEFAULT_DB_TYPE=${NSS_DEFAULT_DB_TYPE:-"sql"}
+        NSS_DEFAULT_DB_TYPE="dbm"
         export NSS_DEFAULT_DB_TYPE
     fi
 
diff -up ./tests/remote/Makefile.sql-default-tests ./tests/remote/Makefile
--- ./tests/remote/Makefile.sql-default-tests	2021-05-28 02:50:43.000000000 -0700
+++ ./tests/remote/Makefile	2021-06-03 15:44:45.771708842 -0700
@@ -56,7 +56,7 @@ ifeq ($(OS_TARGET),Android)
 TEST_SHELL?=$$HOME/bin/sh
 ANDROID_PORT?="2222"
 #Define the subset of tests that is known to work on Android
-NSS_CYCLES?="standard pkix sharedb"
+NSS_CYCLES?="standard pkix upgradedb sharedb"
 NSS_TESTS?="cipher lowhash libpkix cert dbtests tools sdr crmf smime ssl ocsp merge pkits chains"
 NSS_SSL_TESTS?="crl normal_normal iopr"
 NSS_SSL_RUN?="cov auth stress"
diff -up ./tests/all.sh.sql-default-tests ./tests/all.sh
--- ./tests/all.sh.sql-default-tests	2021-06-03 15:44:45.759708770 -0700
+++ ./tests/all.sh	2021-06-03 15:50:12.649678081 -0700
@@ -51,10 +51,10 @@
 #   pkix         - run test suites with PKIX enabled
 #   upgradedb    - upgrade existing certificate databases to shareable
 #                  format (creates them if doesn't exist yet) and run
-#                  test suites with those databases. Requires to enable libdm.
+#                  test suites with those databases.
 #   sharedb      - run test suites with shareable database format
 #                  enabled (databases are created directly to this
-#                  format). This is the default and doesn't need to be run separately.
+#                  format).
 #   threadunsafe - run test suites with thread unsafe environment variable
 #                  so simulate running NSS locking for PKCS #11 modules which
 #                  are not thread safe.
@@ -137,7 +137,7 @@ run_tests()
 }
 
 ########################## run_cycle_standard ##########################
 # run test suites with sql database (no PKIX)
 ########################################################################
 run_cycle_standard()
 {
@@ -146,7 +146,7 @@ run_cycle_standard()
     TESTS="${ALL_TESTS}"
     TESTS_SKIP="libpkix pkits"
 
-    NSS_DEFAULT_DB_TYPE=${NSS_DEFAULT_DB_TYPE:-"sql"}
+    NSS_DEFAULT_DB_TYPE=dbm
     export NSS_DEFAULT_DB_TYPE
 
     run_tests
@@ -323,7 +323,7 @@ if [ -z "${INIT_SOURCED}" -o "${INIT_SOU
     . ./init.sh
 fi
 
-cycles="standard pkix threadunsafe"
+cycles="standard pkix upgradedb sharedb threadunsafe"
 CYCLES=${NSS_CYCLES:-$cycles}
 
 NO_INIT_SUPPORT=`certutil --build-flags |grep -cw NSS_NO_INIT_SUPPORT`
@@ -137,7 +137,7 @@ run_tests()
 
 ########################## run_cycle_standard ##########################
-# run test suites with sql database (no PKIX)
+# run test suites with dbm database (no PKIX, no sharedb)
 ########################################################################
 run_cycle_standard()